From d1eed44a90d76c3025b0e708d1aaaede0d6acb7d Mon Sep 17 00:00:00 2001
From: Nick <nick.guenther@polymtl.ca>
Date: Sun, 19 Sep 2021 19:51:30 -0400
Subject: [PATCH] Take public keys at newline, instead of on EOF

This is better UX: many people these days are unaware of what the EOF character is, and instead expect programs to react on pressing enter.

`sskm` and the docs (https://gitolite.com/gitolite/contrib/sskm.html#step-1-adding-the-key) show adding a key by piping in. However in my experience actually deploying gitolite, people are often more comfortable pasting a key in: it is easier to cat + copy + paste than to scp. But with `safe_stdin` these people are left hanging, totally at a loss of how to administer the server or administer their own keys. To support these people, I have patched my deployment with this, and it has already saved a lot of tech support time.

I realize that 'safe_stdin' has 'safe' in its name for a reason. I hope you will consider the tradeoff.
---
 src/commands/sskm | 13 ++-----------
 1 file changed, 2 insertions(+), 11 deletions(-)

diff --git a/src/commands/sskm b/src/commands/sskm
index eb51f69..a94939a 100755
--- a/src/commands/sskm
+++ b/src/commands/sskm
@@ -92,7 +92,8 @@ if ( $keytype eq '' ) {
     if ( $operation eq 'add' ) {
         print STDERR "please supply the new key on STDIN.  (I recommend you
         don't try to do this interactively, but use a pipe)\n";
-        kf_add( $gl_user, $keyid, safe_stdin() );
+        my $keymaterial = <STDIN>;
+        kf_add( $gl_user, $keyid, $keymaterial );
     } elsif ( $operation eq 'del' ) {
         kf_del( $gl_user, $keyid );
     } elsif ( $operation eq 'confirm-del' ) {
@@ -143,16 +144,6 @@ sub fingerprint {
     return $fp;
 }
 
-sub safe_stdin {
-    # read one line from STDIN
-    my $data;
-    my $ret = read STDIN, $data, 4096;
-    # current pubkeys are approx 400 bytes so we go a little overboard
-    die "could not read pubkey data" . ( defined($ret) ? "" : ": $!" ) . "\n" unless $ret;
-    die "pubkey data seems to have more than one line\n" if $data =~ /\n./;
-    return $data;
-}
-
 sub hushed_git {
     local (*STDOUT) = \*STDOUT;
     local (*STDERR) = \*STDERR;
-- 
2.33.0

